==> Aurora_OS-5.1.3.85-MB2-Aurora_SDK_Target-aarch64.tar.7z: usr/include/libsailfishpolicy/policytypes.h <==
/**
 * SPDX-FileCopyrightText: 2023-2024 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: Proprietary
 */

#ifndef POLICYTYPE_H
#define POLICYTYPE_H

#include <QtGlobal>

/*!
  \namespace Sailfish::PolicyTypes
  \internal
*/

#ifdef  __cplusplus
namespace Sailfish {
namespace PolicyTypes {
#endif

enum PolicyType {
    Unknown,
    CameraEnabled,
    LocationSettingsEnabled,
    OsUpdatesEnabled,
    DeveloperModeSettingsEnabled,
    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
    ApplicationInstallationEnabled,
    WlanToggleEnabled,
    InternetSharingEnabled,
    DeviceResetEnabled,
    ScreenshotEnabled,
    MobileNetworkSettingsEnabled,
    UsbMassStorageEnabled Q_DECL_DEPRECATED,
    UsbDeveloperModeEnabled,
    UsbMtpEnabled,
    UsbHostEnabled Q_DECL_DEPRECATED,
    UsbConnectionSharingEnabled Q_DECL_DEPRECATED,
    UsbDiagnosticModeEnabled Q_DECL_DEPRECATED,
    UsbAdbEnabled Q_DECL_DEPRECATED,
    DateTimeSettingsEnabled,
    MicrophoneEnabled,
    FlightModeToggleEnabled,
    NetworkProxySettingsEnabled,
    NetworkDataCounterSettingsEnabled,
    CallStatisticsSettingsEnabled,
    CellularTechnologySettingsEnabled,
    MobileDataAccessPointSettingsEnabled,
    VpnConnectionSettingsEnabled,
    VpnConfigurationSettingsEnabled,
    BrowserEnabled,
    AccountCreationEnabled,
    BluetoothToggleEnabled,
    SdMountEnabled,
    UsbMountEnabled,
    GlobalServicesSettingsEnabled,
    VoiceCallEnabled,
    SMSEnabled,
    SimPinningSettingsEnabled,
    SimSlotsSettingsEnabled,
    DevelSuEnabled,
    NfcToggleEnabled,
    UserReportExportEnabled,
};

#ifdef  __cplusplus
}
}

#endif

#endif

==> Aurora_OS-5.1.6.110-MB2-Aurora_SDK_Target-aarch64.tar.7z: usr/include/libsailfishpolicy/policytypes.h <==
/**
 * SPDX-FileCopyrightText: 2023-2024 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: Proprietary
 */

#ifndef POLICYTYPE_H
#define POLICYTYPE_H

#include <QtGlobal>

/*!
  \namespace Sailfish::PolicyTypes
  \internal
*/

#ifdef  __cplusplus
namespace Sailfish {
namespace PolicyTypes {
#endif

enum PolicyType {
    Unknown,
    CameraEnabled,
    LocationSettingsEnabled,
    OsUpdatesEnabled,
    DeveloperModeSettingsEnabled,
    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
    ApplicationInstallationEnabled,
    WlanToggleEnabled,
    InternetSharingEnabled,
    DeviceResetEnabled,
    ScreenshotEnabled,
    MobileNetworkSettingsEnabled,
    UsbMassStorageEnabled Q_DECL_DEPRECATED,
    UsbDeveloperModeEnabled Q_DECL_DEPRECATED,
    UsbMtpEnabled,
    UsbHostEnabled Q_DECL_DEPRECATED,
    UsbConnectionSharingEnabled Q_DECL_DEPRECATED,
    UsbDiagnosticModeEnabled Q_DECL_DEPRECATED,
    UsbAdbEnabled Q_DECL_DEPRECATED,
    DateTimeSettingsEnabled,
    MicrophoneEnabled,
    FlightModeToggleEnabled,
    NetworkProxySettingsEnabled,
    NetworkDataCounterSettingsEnabled,
    CallStatisticsSettingsEnabled,
    CellularTechnologySettingsEnabled,
    MobileDataAccessPointSettingsEnabled,
    VpnConnectionSettingsEnabled,
    VpnConfigurationSettingsEnabled,
    BrowserEnabled,
    AccountCreationEnabled,
    BluetoothToggleEnabled,
    SdMountEnabled,
    UsbMountEnabled,
    GlobalServicesSettingsEnabled,
    VoiceCallEnabled,
    SMSEnabled,
    SimPinningSettingsEnabled,
    SimSlotsSettingsEnabled,
    DevelSuEnabled,
    NfcToggleEnabled,
    UserReportExportEnabled,
    RemoteAccessDeveloperModeEnabled,
    BackupRestoreEnabled,
};

#ifdef  __cplusplus
}
}

#endif

#endif
